@ ------------------------------------ GetPar.g ----------------------------

   Geschrieben am 22.05.2000 von Alfred Maussner

   Letzte nderung: 10.04.2002

   Zweck: Parameterwerte fuer berechenbare Konjunkturmodelle aus den Daten
          in data.txt berechnen.

 ------------------------------------------------------------------------  @

/* Bibliotheken */
library user, pgraph dge;

/* Daten einlesen */
load path=d:\Tbk\tb5\data;

load data[120,37]=data.txt;

/* Daten auf die Periode 75.i bis 89.iv begrenzen */
data=data[61:120,.];

/* Preisindizes zur Berechnung realer und nominaler Groessen */
pbip=data[.,15]/100;
pinvest=(data[.,7]./data[.,4]);

 bt=data[.,22];                        @ Wohnbevoelkerung in 1000 Personen    @
  yt=data[.,2]-(data[.,23]./pbip);     @ Reales BIP zu Faktorkosten in Mrd DM @
 ytk=(yt./bt)*1e6;                     @ Reales BIP zu Faktorkosten in DM pro Kopf und Quartal @
  it=data[.,4];                        @ Reale Anlageinvestitionen in Mrd DM  @
 itk=(data[.,4]./bt)*1e6;              @ Reale Anlageinvestitionen in DM pro Kopf und Quartal @
  ct=data[.,3];                        @ Realer privater Verbrauch in Mrd DM  @
 ctk=(data[.,3]./bt)*1e6;              @ Realer privater Verbrauch in DM pro Kopf und Quartal @
 ytn=(data[.,2].*pbip)-data[.,23];     @ Nominales BIP zu Faktorkosten in Mrd DM @
  ht=data[.,17];                       @ Arbeitsstunden in Mill. Stunden @
 htk=(data[.,17]./bt)*1000;            @ Arbeitsstunden in Stunden pro Kopf @
  kt=GetKapital;                       @ Realer Kapitalstock            @
 ktk=(kt./bt)*1e6;                     @ Realer Kapitalstock pro Kopf @
 ntk=(htk/(16*90));                    @ Arbeitsstunden pro Kopf als Anteil von 1440 Stunden je Quartal @
 wt =(data[.,16]./data[.,36])*1000;    @ DM je Arbeitsstunde der abhaengig Beschaeftigten               @
 wt = (100*wt)./data[.,37];            @ Kaufkraft DM je Arbeitsstund der abhaenig Beschaeftigten       @

 /* nstar */
 n=meanc(ntk);
 
 yk=meanc(yt./kt);
 
/* Wachstumstrend Output pro Kopf */
{trend1,resid1,b1}=LTREND(ln(ytk));  @ Reales Bip zu Faktorkosten pro Kopf und Quartal @
a=exp(b1[1,2]);

/* Kalibrieren von delta */
dreal=data[.,6]./pinvest;
delta=meanc(dreal./kt);

/* Kalibrieren von alpha */
alpha=GetAlpha;

/* Verwendet man die von King, Plosser und Rebelo
** benutzte Aktienrendite erhlt man
*/
rstar1=(data[rows(data),34]./data[1,34])^(1/(rows(data)-1));
rstar2=(data[rows(data),35]./data[1,35])^(1/(rows(data)-1));

/* Der ex post Realzins auf Drei-Monats-Gelder ist */
dp=Rate(data[.,15],1);                    @ vierteljaehrliche Preisaenderungsrate @
z1=(1+(data[.,29]/100))^(1/4) - 1;        @ Zins auf 3 Monatsgelder pro Quartal   @
rz1=z1[1:rows(z1)-1]-dp;
rstar3=meanc(rz1);

/* Solow-Residuum: Es wird konstruiert aus
**
**  z=y/((a*h)^alpha)*(k^(1-alpha)).
**
**  Dabei wird der Effizienzfaktor a aus dem Wachstumstrend der Pro-
**  Kopf-Produktion geschaetzt.
**
** Der Abweichung des Solow-Residuums von seinem Durchschnitt wird ein AR(1)-Prozess
** durch OLS-Schaetzung angepasst.
*/

at=zeros(rows(yt),1);at[1]=1;
i=1;
do until i>rows(at)-1;
  at[i+1]=at[i]*a;
  i=i+1;
endo;

zt=yt./((((at.*ht))^alpha).*(kt^(1-alpha)));

zhut=(zt-meanc(zt))./meanc(zt);

{rho,stderr,twert,pwert,resid,rbar}=MyOls(trimr(zhut,1,0),trimr(zhut,0,1),"");

sigma=(resid'*resid)/(rows(resid)-1);
sigma=sqrt(sigma);

/* Momente berechnen */
yt=HPFilter(ln(ytk),1600);
it=HPFilter(ln(itk),1600);
ct=HPFilter(ln(ctk),1600);
ht=HPFilter(ln(htk),1600);
wt=HPFilter(ln(wt),1600);
x=(yt~it~ct~ht~wt);
vc=vcx(x);
cr=corrx(trimr(x,1,0)~trimr(x,0,1));

/* Daten fuer die Ausgabe zusammenstellen */
out="Output  "~"" |
    "Investme"~"nt" |
    "Consumpt"~"ion"|
    "Hours   "~""   |
    "Real Wag"~"e";

out=out~sqrt(diag(vc))*100;  @ Standardabweichungen @
out=out~cr[1:5,1];           @ Kreuzkorrelation mit der Produktion @
out=out~diag(cr[1:5,6:10]);  @ Autokorrelationen erster Ordnung @

mask=(0~0~1~1~1);
fmt={"-*.*s" 8 8, "-*.*s" 8 8, "*.*lf" 8 2, "*.*lf" 8 2,"*.*lf" 8 2};

output file=d:\tbk\tb5\data\GetMom1.txt reset;
i=printfm(out,mask,fmt);
?"Column 1: Variable name";
?"Column 2: Standard deviation";
?"Column 3: Cross correlation with output";
?"Column 4: Firt order autocorrelation";

output off;

output file=d:\tbk\tb5\data\GetPar1.txt reset;

?"Results:";
?"a     = " ftos(a,"*.*lf",6,4);
?"Alpha = " ftos(alpha,"*.*lf",6,2);
?"Delta = " ftos(delta,"*.*lf",6,3);
?"n     = " ftos(n,"*.*lf",6,2);
?"Rstar1= " ftos(rstar1,"*.*lf",8,4);
?"Rstar2= " ftos(rstar2,"*.*lf",8,4);
?"Rstar3= " ftos(rstar3,"*.*lf",8,4);
?"yk    = " ftos(yk,"*.*lf",8,4);
?"Rho   = " ftos(rho,"*.*lf",6,3);
?"Sigma = " ftos(Sigma,"*.*lf",8,4);

output off;
end;

/* -------------------------------- Unterprogramme ------------------------- */

/* GetAlpha berechnet die Lohnquote 
**
** Lohnquote: Das reale Bruttolohneinkommen wird ergaenzt um ein hypothetisches
**            Lohneinkommen fuer die Selbstaendigen in Hoehe des durchschnittlichen
**            Lohneinkommens der Unselbstaendigen. Dieses Lohneinkommen wird auf
**            das Bruttoinlandsprodukt zu Faktorkosten bezogen.
*/

proc(1)=GetAlpha;

   local l, alpha;
       
       l=100*(data[.,16]./data[.,15]);
       l=l+(l./data[.,18]).*data[.,19]; 

  alpha=meanc(l./yt);

 retp(alpha);
endp;

/* GetKapital: Berechnet den Kapitalstock */
proc(1)=GetKapital;

    local data2, preisindex, dreal, irealnetto, kj, kq, kt, i, t, a;

    load data2[31,7]  =NettoAV.txt;      @ Jahresdaten 60-90            @
    data2=data2[16:31,.];                @ kuerzen auf 75 bis 89        @

    preisindex=data[.,7]./data[.,4];     @ Preisindex der Investitionen @
    dreal=data[.,6]./preisindex;         @ Reale Abschreibunen          @
    irealnetto=data[.,4]-dreal;          @ Reale Nettoinvestitionen @

    kj=data2[.,2]+data2[.,3]+data2[.,4]+data2[.,5]+data2[.,7];

   /* Berechnung des Kapitalstocks:
   **
   ** Da die Summe der Nettoinvestitionen eines Jahres in der Regel nicht
   ** der Differenz zweier benachbarter Jahreswerte des Kapitals entspricht,
   ** werden die Investitionen gleichmaessig nach oben oder unter skaliert:
   **
   ** a=(kj[t+1]-kj[t])/sumc(I[t,1:4])
   **
   ** Die ausgewiesenen Kapitalbestaende sind Jahresanfangswerte.
   */

   kq=zeros(rows(irealnetto)+1,1);kt=ones(rows(kq),1).*miss(1,1);
   i=1;t=1;
   do until i>rows(kj)-1;
 
            a=(kj[i+1]-kj[i])/sumc(irealnetto[4*(i-1)+1:4*(i-1)+4]);
       kq[t]=kj[i];
     kq[t+1]=kq[t]+a*irealnetto[4*(i-1)+1];
     kq[t+2]=kq[t+1]+a*irealnetto[4*(i-1)+2];kt[t]=kj[i];
     kq[t+3]=kq[t+2]+a*irealnetto[4*(i-1)+3];
     kq[t+4]=kq[t+3]+a*irealnetto[4*(i-1)+4];

           i=i+1;
           t=t+4;  
   endo;
   kq=kq[1:rows(kq)-1];
   kt=kt[1:rows(kt)-1];
   MyGraphSettings(0);
   _plctrl=(0|-1|0);
   xy(seqa(76,0.25,rows(kq)),kq~kt);

retp(kq);
endp;
