@ -------------------------------------- Ramsey1b.g -----------------------------
  
   Date:    07/30/2002
   Author:  Alfred Maussner
   Purpose: Solve the set of non-linear equations from Example 1.1.1
            using the modified Newton-Raphson method

-------------------------------------------------------------------------------- @

new; @ clear memory @

library pgraph, dge;

/* The parameters of the problem */
alpha=0.5;  @ elasticity of production with respect to capital @
rho=0.35;   @ substitution parameter in utility function       @
t=59;        @ length of planning period                        @
k0=0.1;      @ intial value of capital stock                    @


/* Compute stationary solution to find reasonable starting values */
ks=alpha^(1/(1-alpha)); 
cs=ks^alpha - ks;
x0=(ones(t+1,1).*cs)|(ones(t,1).*ks);

/* Uncomment this section of code if you want to solve the 2*t+1 equations
** in c_0, c_1, ..., c_T and k_1, k_2, ..., k_T. 
**
** bounds=zeros(2*t+1,1)~ones(2*t+1,1).*10;
**
** bsec=hsec;
**{fx,x}=FixVMN(x0,bounds,&Sys1);
*/

/* This part solves the system of t equations in k_1, k_2, ..., k_T */
x0=ones(t,1).*ks;
bounds=zeros(t,1)~ones(t,2).*2;
bsec=hsec;
{fx,x}=FixVMN(x0,bounds,&Sys2);
?"Runtime= " etstr(hsec-bsec);

/* Plott the sequence of capital stocks */
GraphSettings;
_plwidth=10;
xlabel("Time");
ylabel("Capital Stock");
xtics(0,T+2,5,0);
@ytics(0,0.225,0.025,0);@
xy(seqa(0,1,t+2),k0|x|0);

/* Write the solution to a file on disk */
output file="Ramsey1b.txt" reset;
?seqa(0,1,t+2)~(k0|x|0);
output off;
ende:
end;  

/* Subroutines */

proc(1)=Sys1(x0); @ defines the procedure whose zero delivers the solution to the system in c and k@

   local ct, f1, kt, f2, nx, i;

   nx=rows(x0);
   ct=x0[1:t+1];
   kt=x0[t+2:nx];
   f1=zeros(t+1,1);
   f2=zeros(t,1);
   f1[1]=(k0^alpha)-kt[1]-ct[1];
   f2[1]=((1/alpha)*((ct[1]/ct[2])^(rho-1)))^(1/(alpha-1))-kt[1];
   i=2;   
   do until i>t;      
        f1[i]=(kt[i-1]^alpha)-kt[i]-ct[i];
        f2[i]=((1/alpha)*((ct[i]/ct[i+1])^(rho-1)))^(1/(alpha-1))-kt[i];
            i=i+1;
   endo;
   f1[i]=kt[i-1]^alpha-ct[i];
   
retp(f1|f2);

endp;

proc(1)=Sys2(x); @ defines the procedure whose zero is the solution to the system in k @

   local f, i, nx;
   nx=rows(x);
   f=zeros(nx,1);
   f[1]=((((x[1]^alpha) - x[2])/((k0^alpha)-x[1]))^(1-rho))-alpha*(x[1]^(alpha-1));
      i=2;
      do until i>(nx-1);
          f[i]=((((x[i]^alpha) - x[i+1])/((x[i-1]^alpha)-x[i]))^(1-rho))-alpha*(x[i]^(alpha-1));
             i=i+1;
      endo;
          f[i]=(((x[i]^alpha)/((x[i-1]^alpha)-x[i]))^(1-rho))-alpha*(x[i]^(alpha-1));

 retp(f);

endp;
