@ ------------------------------- Ramsey1a.g --------------------------

  Date:     07/30/2002
  Author:   Alfred Maussner
  Purpose:  Try to solve Example 1.1.1 using the Gauss routine sqpSolve

---------------------------------------------------------------------- @

new; @ clear memory @

library pgraph, dge;

/* Parameters of the model */
alpha=0.35;  @ elasticity of production with respect to capital @
rho=0.5;     @ substitution parameter in utility function       @
t=45;        @ length of planning period                        @
k0=0.1;      @ intial value of capital stock                    @

/* The next section provides the code to solve the problem
** using the build-in Gauss routine sqpSolve.
*/

ks=alpha^(1/(1-alpha));  @ use stationary solution for starting values @
cs=ks^alpha - ks;

x0=(ones(T,1)*cs)|(ones(T,1).*ks);

_sqp_C=eye(2*t);        @ this specifies the non-negativity constraints on c and k @
_sqp_D=zeros(2*t,1);
_sqp_Bounds=zeros(2*T,1)~ones(2*T,1);
_sqp_IneqProc=&RC;      @ pointer the function defining the resource constraints @


{ x,f,lagr,retcode } = sqpSolve(&U,x0); @ Call to the routine that does the computations @

end;


/* --------------------------- Subroutines ------------------------------ */

/* Defintion of utiltiy function */

proc(1)=U(x);

   local fx, i;
   
   fx=0.0;
   i =1;
   do until i>t;
      fx = fx+x[i]^rho;
      i  = i+1;
   endo;
   fx=fx^(1/rho);
   
retp(-fx);

endp;

/* Definition of the set of resource constraints */   

proc(1)=RC(x);

  local fx, i;
  fx=zeros(t,1);
  fx[1]=k0^alpha-x[1]-x[t+1];
  i=2;
  do until i>t;
     fx[i] = (x[t+i-1]^alpha)-x[i]-x[t+i];
         i = i+1;
  endo;
  
retp(fx);

endp;       
   
   
